/**
 * Copyright (C) 2007 - Bull S.A.S.
 *
 * CAROL: Common Architecture for RMI ObjectWeb Layer
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JClientRequestInterceptorWrapper.java 1513 2007-11-25 12:22:17Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.carol.rmi.jrmp.interceptor.wrapper;

import java.io.IOException;

import org.ow2.carol.rmi.jrmp.interceptor.api.JClientRequestInfo;
import org.ow2.carol.rmi.jrmp.interceptor.spi.JClientRequestInterceptor;

@SuppressWarnings("deprecation")
final class JClientRequestInterceptorWrapper
implements org.objectweb.carol.rmi.jrmp.interceptor.JClientRequestInterceptor, JClientRequestInterceptor {

    /**
     * Id for serializable class.
     */
    private static final long serialVersionUID = 4311802443285921290L;

    private final org.objectweb.carol.rmi.jrmp.interceptor.JClientRequestInterceptor interceptor;

    private final JClientRequestInterceptor newinterceptor;

    JClientRequestInterceptorWrapper(org.objectweb.carol.rmi.jrmp.interceptor.JClientRequestInterceptor interceptor) {
        this.interceptor = interceptor;
        newinterceptor = null;
    }

    JClientRequestInterceptorWrapper(JClientRequestInterceptor interceptor) {
        newinterceptor = interceptor;
        this.interceptor = null;
    }

    public String name() {
        if(interceptor != null) {
            return interceptor.name();
        } else {
            return newinterceptor.name();
        }
    }

    public void receive_exception(JClientRequestInfo jri) throws IOException {
        interceptor.receive_exception(new JClientRequestInfoWrapper(jri));
    }

    public void receive_other(JClientRequestInfo jri) throws IOException {
        interceptor.receive_other(new JClientRequestInfoWrapper(jri));
    }

    public void receive_reply(JClientRequestInfo jri) throws IOException {
        interceptor.receive_reply(new JClientRequestInfoWrapper(jri));
    }

    public void send_poll(JClientRequestInfo jri) throws IOException {
        interceptor.send_poll(new JClientRequestInfoWrapper(jri));
    }

    public void send_request(JClientRequestInfo jri) throws IOException {
        interceptor.send_request(new JClientRequestInfoWrapper(jri));
    }

    public void receive_exception(
            org.objectweb.carol.rmi.jrmp.interceptor.JClientRequestInfo jri)
            throws IOException {
        newinterceptor.receive_exception(new JClientRequestInfoWrapper(jri));
    }

    public void receive_other(
            org.objectweb.carol.rmi.jrmp.interceptor.JClientRequestInfo jri)
            throws IOException {
        newinterceptor.receive_other(new JClientRequestInfoWrapper(jri));
    }

    public void receive_reply(
            org.objectweb.carol.rmi.jrmp.interceptor.JClientRequestInfo jri)
            throws IOException {
        newinterceptor.receive_reply(new JClientRequestInfoWrapper(jri));
    }

    public void send_poll(
            org.objectweb.carol.rmi.jrmp.interceptor.JClientRequestInfo jri)
            throws IOException {
        newinterceptor.send_poll(new JClientRequestInfoWrapper(jri));
    }

    public void send_request(
            org.objectweb.carol.rmi.jrmp.interceptor.JClientRequestInfo jri)
            throws IOException {
        newinterceptor.send_request(new JClientRequestInfoWrapper(jri));
    }

}
